/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-20 17:15:49
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-10-08 18:04:25
 * @FilePath: \Game-Backstage-Management-System\src\hooks\useTable.ts
 * @Description:
 *
 */
import type { ResponseInfo } from '@/types/res'
import axiosInstance from '../utils/axios/axiosInstance'

import { loadResource } from '@/utils/resource'

import type { TablePaginationSetting, DialogSetting } from '@/types/table'
import { type FormInstance } from 'element-plus'

export function useTable(tableData: Array<any>, paginationSetting: TablePaginationSetting) {
  // const { analysisResCode } = useRequest()

  const getTableData = (url: string, option: any, isPagination: boolean = false) => {
    return new Promise(async (reslove, reject) => {
      try {
        await axiosInstance.post(url, option).then(async (result) => {
          let info = JSON.parse(JSON.stringify(result)) as ResponseInfo
          let data = info.data

          // 加载图片资源
          // 如果有头像字段，就去加载这个头像字段，缓存起来
          const loadImg = async () => {
            return new Promise((resolve) => {
              let resList: Array<Promise<any>> = []
              if (data && data.length > 0) {
                data.slice(0, data.length).map(async (item: any) => {
                  if (item.head) {
                    const loadHead = loadResource(item.head).then((res) => {
                      item.head = res
                    })
                    resList.push(loadHead)
                  }
                })
              }
              Promise.allSettled(resList).then(() => {
                resolve(true)
              })
            })
          }
          await loadImg()

          // 如果开启了分页，那么默认这个tabledata是一个二维数组，每个位置对应当页的一个数据数组
          // 没开启则是一个一维数组，直接赋值
          if (data && data.length > 0) {
            if (isPagination) tableData[paginationSetting.currentPage] = data
            else tableData.splice(0, tableData.length, ...data)
          } else {
            tableData.splice(0, tableData.length)
          }

          // 如果有的接口没有返回count属性，就需要自己写
          // 这个length，如果数组长为0，则需要自己赋值，不然会报错
          if (info.count) paginationSetting.total = info.count
          else if (info.data) {
            paginationSetting.total = info.data.length
          } else {
            paginationSetting.total = 0
          }
          reslove(true)
        })
      } catch (err) {
        console.log(err)
        reject(err)
        throw new Error('网络请求错误')
      }
    })
  }

  // 对话框关闭
  const dialogClose = (formEl: FormInstance | undefined, dialogParam: DialogSetting) => {
    if (!formEl) return

    dialogParam.dialogVisible = false
    formEl.resetFields()
  }

  return {
    getTableData,
    dialogClose
  }
}
